==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/vo/WeighingInfoVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 称重信息
 * 
 * @author generator
 * 
 */
public class WeighingInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String numberPlate; // 车牌号
    private Date weighingTime; // 称重时间
    private Long purchasereceiptId; // 收货单ID
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    private Long firstTimeId; // 上次称重ID
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String billCode; // 单据编号
    private BigDecimal  weight;//称重重量

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/vo/WeighingInfoVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 称重信息
 * 
 * @author generator
 * 
 */
public class WeighingInfoVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date weighingTime; // 称重时间
    private Long purchasereceiptId; // 收货单ID
    private Long poundRoomId; // 磅房ID
    private Long cameraId; // 摄像头ID
    private Long weigherId; // 磅头ID
    private Integer weighingMethod; // 称重方式 0,一次称重  1,毛重  2,皮重 
    private Integer print; // 是否打印   
    private Integer sendOrReceive; // 收发类型 0,收货 1,发货  
    private Long firstTimeId; // 上次称重ID
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String billCode; // 单据编号
    private BigDecimal  weight;//称重重量

    public BigDecimal getWeight() {
        return weight;
    }

    public void setWeight(BigDecimal weight) {
        this.weight = weight;
    }

    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getWeighingTime() {
        return weighingTime;
    }

    public void setWeighingTime(Date weighingTime) {
        this.weighingTime = weighingTime;
    }
    public Long getPurchasereceiptId() {
        return purchasereceiptId;
    }

    public void setPurchasereceiptId(Long purchasereceiptId) {
        this.purchasereceiptId = purchasereceiptId;
    }
    public Long getPoundRoomId() {
        return poundRoomId;
    }

    public void setPoundRoomId(Long poundRoomId) {
        this.poundRoomId = poundRoomId;
    }
    public Long getCameraId() {
        return cameraId;
    }

    public void setCameraId(Long cameraId) {
        this.cameraId = cameraId;
    }
    public Long getWeigherId() {
        return weigherId;
    }

    public void setWeigherId(Long weigherId) {
        this.weigherId = weigherId;
    }
    public Integer getWeighingMethod() {
        return weighingMethod;
    }

    public void setWeighingMethod(Integer weighingMethod) {
        this.weighingMethod = weighingMethod;
    }
    public Integer getPrint() {
        return print;
    }

    public void setPrint(Integer print) {
        this.print = print;
    }
    public Integer getSendOrReceive() {
        return sendOrReceive;
    }

    public void setSendOrReceive(Integer sendOrReceive) {
        this.sendOrReceive = sendOrReceive;
    }
    public Long getFirstTimeId() {
        return firstTimeId;
    }

    public void setFirstTimeId(Long firstTimeId) {
        this.firstTimeId = firstTimeId;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    
}
